Builder

Struct Builder 

pub struct Builder { /* private fields */ }
A builder for a log filter.

It can be used to parse a set of directives from a string before building a Filter instance.

Example

use env_filter::Builder;

let mut builder = Builder::new();

// Parse a logging filter from an environment variable.
if let Ok(rust_log) = env::var("RUST_LOG") {
    builder.parse(&rust_log);
}

let filter = builder.build();

Implementations

Source

impl Builder

pub fn new() -> Builder

Initializes the filter builder with defaults.

pub fn from_env(env: &str) -> Builder

Initializes the filter builder from an environment.

pub fn filter_module(&mut self, module: &str, level: LevelFilter) -> &mut Self

Adds a directive to the filter for a specific module.

pub fn filter_level(&mut self, level: LevelFilter) -> &mut Self

Adds a directive to the filter for all modules.

pub fn filter_component( &mut self, component: &str, level: LevelFilter, negated: bool, ) -> &mut Self

Adds a component directive to the filter.

pub fn filter_topic( &mut self, component: &str, topic: &str, level: LevelFilter, negated: bool, ) -> &mut Self

Adds a component + topic directive to the filter.

pub fn filter_key_value( &mut self, key: &str, value: &str, negated: bool, ) -> &mut Self

Adds a key/value filter to the overall filter.

pub fn parse(&mut self, filters: &str) -> &mut Self

Parses the directives string.

See the Enabling Logging section for more details.

pub fn try_parse(&mut self, filters: &str) -> Result<&mut Self, ParseError>

Parses the directive string, returning an error if the given directive string is invalid.

See the Enabling Logging section for more details.

pub fn build(&mut self) -> Filter

Build a log filter.